package com.unitreactnativecomponents.nativeModules.sharefile

import android.content.Intent
import android.net.Uri
import android.util.Base64
import androidx.core.content.FileProvider
import com.facebook.react.bridge.Promise
import com.facebook.react.bridge.ReactApplicationContext
import com.facebook.react.bridge.ReactContextBaseJavaModule
import com.facebook.react.bridge.ReactMethod
import java.io.File
import java.io.FileOutputStream
import java.io.IOException

class UNShareFile(var reactContext: ReactApplicationContext) :
  ReactContextBaseJavaModule(reactContext) {
  @ReactMethod
  fun share(base64pdf: String, filename: String, promise: Promise) {
    try {
      cleanSharedFiles()
      val pdfFile = writeFile(base64pdf, filename)
      shareFile(pdfFile)
      promise.resolve(true)
    } catch (e: IOException) {
      promise.reject(e)
    }
  }

  private fun cleanSharedFiles() {
    val directoryPath = directoryPath
    if (directoryPath.isDirectory) {
      for (file in directoryPath.list()) {
        File(directoryPath, file).delete()
      }
    }
  }

  @Throws(IOException::class)
  private fun writeFile(base64pdf: String, filename: String): File {
    val directoryPath = directoryPath
    directoryPath.mkdir()
    val newFilePath = File(directoryPath.path, filename)
    val pdfAsBytes = Base64.decode(base64pdf, Base64.DEFAULT)
    FileOutputStream(newFilePath, false).use { os ->
      os.write(pdfAsBytes)
      os.flush()
    }
    return newFilePath
  }

  private fun shareFile(file: File) {
    val outputFileUri: Uri =
      FileProvider.getUriForFile(reactContext, reactContext.packageName + ".provider", file)
    val intentShareFile = Intent(Intent.ACTION_SEND)
    intentShareFile.type = TYPE_PDF
    intentShareFile.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
    intentShareFile.putExtra(Intent.EXTRA_STREAM, outputFileUri)
    intentShareFile.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
    val currentActivity = currentActivity
    currentActivity!!.startActivity(Intent.createChooser(intentShareFile, ""))
  }

  override fun getName(): String {
    return MODULE_NAME
  }

  private val directoryPath: File
    private get() = File(reactContext.currentActivity!!.filesDir, PDF_CACHE_DIR)

  companion object {
    private const val MODULE_NAME = "UNShareFileModule"
    private const val TYPE_PDF: String = "application/pdf"
    private const val PDF_CACHE_DIR = "pdf_documents_for_sharing"
  }
}
