"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.injectUnitPlaidResponse = exports.getACHCreditScript = exports.getACHCreditParams = void 0;
var _bodyScript = require("../../scripts/html/bodyScript");
const getACHCreditParams = props => {
  const plaidAccountFiltersParam = props.plaidAccountFilters ? `plaid-account-filters="${props.plaidAccountFilters.join()}"` : '';
  const plaidLinkCustomizationNameParam = props.plaidLinkCustomizationName ? `plaid-link-customization-name="${props.plaidLinkCustomizationName}"` : '';
  const accountIdParam = props.accountId ? `account-id="${props.accountId}"` : '';
  return `
    ${accountIdParam}
    with-plaid="${props.withPlaid ?? false}"
    is-auto-focus="${props.isAutoFocus ?? false}"
    ${props.fee ? `fee="${props.fee}"` : ''}
    style="height: 100%"
    same-day="${props.sameDay ?? false}"
    show-same-day-selection="${props.showSameDaySelection ?? false}"
    ${plaidAccountFiltersParam}
    ${plaidLinkCustomizationNameParam}
    initial-stage-back-button="${props.initialStageBackButton ?? false}"
    final-stage-done-button="${props.finalStageDoneButton ?? false}"
  `;
};
exports.getACHCreditParams = getACHCreditParams;
const getACHCreditScript = appPackageName => {
  return `
    ${_bodyScript.LISTENERS.unitPlaidTokenCreated}
    ${appPackageName && `window.UnitMobileSDKConfig.androidPackageName='${appPackageName}'`}
    ${_bodyScript.LISTENERS.unitPaymentCreated}
    ${_bodyScript.LISTENERS.unitPaymentInitialStageBackButtonClicked}
    ${_bodyScript.LISTENERS.unitPaymentFinalStageDoneButtonClicked}
    ${_bodyScript.DISPATCH_PLAID_RESPONSE}
    ${_bodyScript.LISTENERS.requestRefresh}

  `;
};
exports.getACHCreditScript = getACHCreditScript;
const injectUnitPlaidResponse = (currentWeb, success) => {
  const successObj = {
    data: {
      publicToken: success.publicToken,
      metadata: success.metadata
    }
  };
  currentWeb?.injectJavaScript(`dispatchPlaidEvent(${JSON.stringify(successObj)})`);
};
exports.injectUnitPlaidResponse = injectUnitPlaidResponse;
//# sourceMappingURL=UNACHCreditComponent.utils.js.map