"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.UNAccountAction = void 0;
var _react = _interopRequireWildcard(require("react"));
var _pageMessage = require("../..//messages/webMessages/pageMessage");
var _unitComponentsMessages = require("../../messages/webMessages/unitComponentsMessages");
var _WebComponent = require("../../webComponent/WebComponent");
var _UNAccountComponent = require("./UNAccountComponent.utils");
var _accountMessage = require("../../messages/webMessages/accountMessage");
var _onLoadMessage = require("../../messages/webMessages/onLoadMessage");
var _bottomSheet = require("../../types/internal/bottomSheet.types");
var _webComponent = require("../../types/internal/webComponent.types");
var _bottomSheetMessage = require("../../messages/nativeMessages/bottomSheetMessage");
var _helpers = require("../../helpers/store/helpers");
var _reactRedux = require("react-redux");
var _SharedEventsSlice = require("../../slices/SharedEventsSlice");
var _useListenerToEvent = require("../../hooks/useListenerToEvent");
var _UNBaseView = require("../../nativeComponents/UNBaseView");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
let UNAccountAction = exports.UNAccountAction = /*#__PURE__*/function (UNAccountAction) {
  UNAccountAction["List"] = "account-list";
  UNAccountAction["Menu"] = "account-menu";
  return UNAccountAction;
}({});
const UNAccountComponent = /*#__PURE__*/_react.default.forwardRef(function UNAccountComponent(props, accountRef) {
  const dispatch = (0, _reactRedux.useDispatch)();
  const [height, setHeight] = (0, _react.useState)(0);
  const webRef = (0, _react.useRef)(null);
  // currentAccountId is used to store the current account id for the "imperative" refresh event.
  const accountIdRef = (0, _react.useRef)(undefined);
  (0, _react.useEffect)(() => {
    accountIdRef.current = props.accountId;
  }, [props.accountId]);
  const handleAccountChanged = account => {
    accountIdRef.current = account.id;
    props.onAccountChanged && props.onAccountChanged(account);
  };
  const requestRefresh = data => {
    (0, _UNAccountComponent.injectRefreshEventIfNeeded)(webRef.current, data);
  };
  const handleRequestLeftToSpendDetails = accountData => {
    props.onRequestLeftToSpendDetails && props.onRequestLeftToSpendDetails(accountData);
  };
  const handleUnitOnLoad = response => {
    if (!props.onLoad) {
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.errors in response) {
      props.onLoad(response);
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.account in response) {
      // AccountsOnLoadResponse;
      const accountResponse = response[_onLoadMessage.RESPONSE_KEYS.account];
      props.onLoad(accountResponse);
      // if accountId is not provided, set the first account as current
      if (!props.accountId && accountResponse.data && accountResponse.data.length > 0) {
        accountIdRef.current = accountResponse.data[0].id;
      }
      return;
    }
    console.error('On Load Error: unexpected response type.');
    return;
  };
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_REFRESH,
    action: requestRefresh
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _accountMessage.AccountMessage.UNIT_ACCOUNT_CHANGED,
    action: handleAccountChanged
  });
  (0, _react.useImperativeHandle)(accountRef, () => ({
    openActionsMenu() {
      (0, _UNAccountComponent.injectOpenActionsMenuScript)(webRef.current);
    },
    openAction(action) {
      (0, _UNAccountComponent.injectRequestAccountActionScript)(webRef.current, action);
    },
    refresh() {
      requestRefresh({
        type: _unitComponentsMessages.UnitRequestRefreshEventTypes.REQUEST_REFRESH_EVENT,
        refEvent: undefined,
        dependencies: [_webComponent.WebComponentType.account.valueOf()],
        resourceId: accountIdRef.current
      });
    }
  }));
  const handleMessage = message => {
    switch (message.type) {
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_ON_LOAD:
        handleUnitOnLoad(message.details);
        break;
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_RENDERING:
        {
          const slotData = {
            componentName: _webComponent.WebComponentType.account,
            componentResourceId: props.accountId,
            requestRenderingEvent: message.details
          };
          const data = {
            type: _bottomSheet.BottomSheetRenderingType.Slot,
            data: slotData
          };
          dispatch((0, _SharedEventsSlice.setEvent)({
            key: _bottomSheetMessage.BottomSheetNativeMessage.REQUEST_RENDERING,
            data
          }));
          break;
        }
      case _pageMessage.PageMessage.PAGE_HEIGHT:
        setHeight(message.details.height);
        break;
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_LEFT_TO_SPEND_DETAILS:
        handleRequestLeftToSpendDetails(message.details);
        break;
    }
  };
  return /*#__PURE__*/_react.default.createElement(_UNBaseView.UNBaseView, {
    style: {
      height,
      width: '100%'
    },
    onLoadError: handleUnitOnLoad,
    fallback: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null)
  }, /*#__PURE__*/_react.default.createElement(_WebComponent.WebComponent, {
    ref: webRef,
    type: _webComponent.WebComponentType.account,
    presentationMode: _webComponent.PresentationMode.Default,
    params: (0, _UNAccountComponent.getAccountParams)(props),
    script: (0, _UNAccountComponent.getAccountScript)(),
    theme: props.theme,
    language: props.language,
    onMessage: message => handleMessage(message),
    isScrollable: false
  }));
});
var _default = exports.default = (0, _helpers.withReduxStoreAndRefForwarding)(UNAccountComponent);
//# sourceMappingURL=UNAccountComponent.js.map