"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _unitComponentsMessages = require("../../messages/webMessages/unitComponentsMessages");
var _pageMessage = require("../../messages/webMessages/pageMessage");
var _WebComponent = require("../../webComponent/WebComponent");
var _UNActivityComponent = require("./UNActivityComponent.utils");
var _onLoadMessage = require("../../messages/webMessages/onLoadMessage");
var _activityMessage = require("../../messages/webMessages/activityMessage");
var _bottomSheet = require("../../types/internal/bottomSheet.types");
var _webComponent = require("../../types/internal/webComponent.types");
var _bottomSheetMessage = require("../../messages/nativeMessages/bottomSheetMessage");
var _helpers = require("../../helpers/store/helpers");
var _SharedEventsSlice = require("../../slices/SharedEventsSlice");
var _reactRedux = require("react-redux");
var _useListenerToEvent = require("../../hooks/useListenerToEvent");
var _UNBaseView = require("../../nativeComponents/UNBaseView");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const DEFAULT_HEIGHT = _reactNative.Dimensions.get('window').height * 0.5;
const UNActivityComponent = /*#__PURE__*/_react.default.forwardRef(function UNActivityComponent(props, activityRef) {
  const dispatch = (0, _reactRedux.useDispatch)();
  const webRef = (0, _react.useRef)(null);
  const [defaultHeight, setDefaultHeight] = (0, _react.useState)();
  const requestRefresh = data => {
    (0, _UNActivityComponent.injectRefreshEventIfNeeded)(webRef.current, data);
  };
  (0, _react.useImperativeHandle)(activityRef, () => ({
    refresh() {
      requestRefresh({
        type: _unitComponentsMessages.UnitRequestRefreshEventTypes.REQUEST_REFRESH_EVENT,
        refEvent: undefined,
        dependencies: [_webComponent.WebComponentType.activity.valueOf()],
        resourceId: ''
      });
    }
  }));
  const dispatchActivityFiltersChanged = query => {
    (0, _UNActivityComponent.injectActivityFiltersChanged)(webRef.current, query);
  };
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_REFRESH,
    action: requestRefresh
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _activityMessage.ActivityMessage.UNIT_ACTIVITY_FILTERS_CHANGED,
    action: dispatchActivityFiltersChanged
  });
  const handleUnitOnLoad = response => {
    if (!props.onLoad) {
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.errors in response) {
      props.onLoad(response);
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.authorizations in response && _onLoadMessage.RESPONSE_KEYS.transactions in response) {
      // ActivityOnLoadResponse;
      const activityOnLoad = {
        data: {
          [_onLoadMessage.RESPONSE_KEYS.authorizations]: response[_onLoadMessage.RESPONSE_KEYS.authorizations].data,
          [_onLoadMessage.RESPONSE_KEYS.transactions]: response[_onLoadMessage.RESPONSE_KEYS.transactions].data
        }
      };
      props.onLoad(activityOnLoad);
      return;
    }
    console.error('On Load Error: unexpected response type');
    return;
  };
  const handleWebViewMessage = message => {
    switch (message.type) {
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_RENDERING:
        {
          const slotData = {
            componentName: _webComponent.WebComponentType.activity,
            componentResourceId: props.accountId,
            requestRenderingEvent: message.details
          };
          const data = {
            type: _bottomSheet.BottomSheetRenderingType.Slot,
            data: slotData
          };
          dispatch((0, _SharedEventsSlice.setEvent)({
            key: _bottomSheetMessage.BottomSheetNativeMessage.REQUEST_RENDERING,
            data
          }));
          break;
        }
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_ON_LOAD:
        handleUnitOnLoad(message.details);
        break;
      case _pageMessage.PageMessage.PAGE_HEIGHT:
        {
          const currentHeight = message.details.height;
          currentHeight === 0 && setDefaultHeight(DEFAULT_HEIGHT);
          break;
        }
    }
  };
  const style = defaultHeight ? {
    height: defaultHeight
  } : {
    flex: 1
  };
  return /*#__PURE__*/_react.default.createElement(_UNBaseView.UNBaseView, {
    style: style,
    onLoadError: handleUnitOnLoad,
    fallback: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null)
  }, /*#__PURE__*/_react.default.createElement(_WebComponent.WebComponent, {
    ref: webRef,
    type: _webComponent.WebComponentType.activity,
    presentationMode: _webComponent.PresentationMode.Inherit,
    params: (0, _UNActivityComponent.getActivityParams)(props),
    onMessage: message => handleWebViewMessage(message),
    nestedScrollEnabled: true,
    theme: props.theme,
    language: props.language,
    script: (0, _UNActivityComponent.getActivityScript)()
  }));
});
var _default = exports.default = (0, _helpers.withReduxStoreAndRefForwarding)(UNActivityComponent);
//# sourceMappingURL=UNActivityComponent.js.map