"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _pageMessage = require("../../messages/webMessages/pageMessage");
var _unitComponentsMessages = require("../../messages/webMessages/unitComponentsMessages");
var _WebComponent = require("../../webComponent/WebComponent");
var _UNCardComponent = require("./UNCardComponent.utils");
var _shared = require("../../types/shared");
var _cardMessage = require("../../messages/webMessages/cardMessage");
var _onLoadMessage = require("../../messages/webMessages/onLoadMessage");
var _bottomSheet = require("../../types/internal/bottomSheet.types");
var _webComponent = require("../../types/internal/webComponent.types");
var _UnitComponentsSdkManager = require("../../unitComponentsSdkManager/UnitComponentsSdkManager");
var _bottomSheetMessage = require("../../messages/nativeMessages/bottomSheetMessage");
var _useLaunchInitialize = require("../../helpers/pushProvisioningService/hooks/useLaunchInitialize");
var _pushProvisioningSlice = require("../../slices/pushProvisioningSlice");
var _reactRedux = require("react-redux");
var _helpers = require("../../helpers/store/helpers");
var _useListenerToEvent = require("../../hooks/useListenerToEvent");
var _SharedEventsSlice = require("../../slices/SharedEventsSlice");
var _UNBaseView = require("../../nativeComponents/UNBaseView");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const UNCardComponent = /*#__PURE__*/_react.default.forwardRef(function UNCardComponent(props, cardRef) {
  const dispatch = (0, _reactRedux.useDispatch)();
  const [height, setHeight] = (0, _react.useState)(0);
  const webRef = (0, _react.useRef)(null);
  const {
    initializePushProvisioning
  } = (0, _useLaunchInitialize.useLaunchInitialize)();
  const {
    signedNonce
  } = (0, _reactRedux.useSelector)(_pushProvisioningSlice.selectWallet);
  (0, _react.useImperativeHandle)(cardRef, () => ({
    openActionsMenu() {
      (0, _UNCardComponent.injectOpenActionsMenuScript)(webRef.current);
    },
    openAction(action) {
      (0, _UNCardComponent.injectRequestCardActionScript)(webRef.current, action);
    },
    showSensitiveData() {
      (0, _UNCardComponent.injectRequestShowSensitiveDataScript)(webRef.current);
    },
    hideSensitiveData() {
      (0, _UNCardComponent.injectRequestHideSensitiveDataScript)(webRef.current);
    }
  }));
  const cardStatusChanged = card => {
    if (props.onStatusChanged) {
      props.onStatusChanged(card);
    }
  };
  const cardActivated = card => {
    if (props.onCardActivated) {
      props.onCardActivated(card);
    }
  };
  const requestRefresh = data => {
    (0, _UNCardComponent.injectRefreshEventIfNeeded)(webRef.current, data, props.cardId);
  };
  const handleUnitOnLoad = response => {
    if (!props.onLoad) {
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.errors in response) {
      props.onLoad(response);
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.card in response) {
      // CardOnLoadResponse
      props.onLoad(response[_onLoadMessage.RESPONSE_KEYS.card]);
      return;
    }
    console.error('On Load Error: unexpected response type');
    return;
  };
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_REFRESH,
    action: requestRefresh
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _cardMessage.CardMessage.CARD_STATUS_CHANGED,
    action: cardStatusChanged
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _cardMessage.CardMessage.CARD_ACTIVATED,
    action: cardActivated
  });
  const handleMessage = message => {
    if (!message || !message.details) return;
    switch (message.type) {
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_RENDERING:
        {
          const slotData = {
            componentName: _webComponent.WebComponentType.card,
            componentResourceId: props.cardId,
            requestRenderingEvent: message.details
          };
          const data = {
            type: _bottomSheet.BottomSheetRenderingType.Slot,
            data: slotData
          };
          dispatch((0, _SharedEventsSlice.setEvent)({
            key: _bottomSheetMessage.BottomSheetNativeMessage.REQUEST_RENDERING,
            data
          }));
          sendActionCallbackIfNeeded(slotData.requestRenderingEvent);
          break;
        }
      case _pageMessage.PageMessage.PAGE_HEIGHT:
        setHeight(message.details.height);
        break;
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_ON_LOAD:
        handleUnitOnLoad(message.details);
        break;
    }
  };
  const sendActionCallbackIfNeeded = requestRenderingEvent => {
    switch (requestRenderingEvent.data.nativeComponentName) {
      case _webComponent.WebComponentType.cardMenu:
        props.onActionsMenuClicked && props.onActionsMenuClicked();
        break;
      case _webComponent.WebComponentType.cardAction:
        {
          // Find the relevant action from the native component
          const actionMatch = requestRenderingEvent.data.nativeComponent.match(/action=([^\s]+)/);
          if (actionMatch && props.onAction) {
            const actionString = actionMatch[1];

            // Check if the actionString matches any value in the UNCardMenuAction enum
            if (Object.values(_shared.UNCardMenuAction).includes(actionString)) {
              props.onAction(actionString);
            }
          }
        }
    }
  };
  (0, _react.useEffect)(() => {
    if (props.pushProvisioningModule) {
      _UnitComponentsSdkManager.UnitComponentsSDK.setPushProvisioningModule(props.pushProvisioningModule);
    }
  }, [props.pushProvisioningModule]);
  (0, _react.useEffect)(() => {
    if (signedNonce || !_UnitComponentsSdkManager.UnitComponentsSDK.getPushProvisionModule()) return;
    initializePushProvisioning();
  }, []);
  return /*#__PURE__*/_react.default.createElement(_UNBaseView.UNBaseView, {
    style: {
      height,
      width: '100%',
      minWidth: 235
    },
    onLoadError: handleUnitOnLoad,
    fallback: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null)
  }, /*#__PURE__*/_react.default.createElement(_WebComponent.WebComponent, {
    ref: webRef,
    type: _webComponent.WebComponentType.card,
    presentationMode: _webComponent.PresentationMode.Default,
    params: (0, _UNCardComponent.getCardParams)(props),
    theme: props.theme,
    language: props.language,
    script: (0, _UNCardComponent.getCardScript)(),
    onMessage: message => handleMessage(message),
    isScrollable: false
  }));
});
var _default = exports.default = (0, _helpers.withReduxStoreAndRefForwarding)(UNCardComponent);
//# sourceMappingURL=UNCardComponent.js.map