"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _pageMessage = require("../../messages/webMessages/pageMessage");
var _WebComponent = require("../../webComponent/WebComponent");
var _webComponent = require("../../types/internal/webComponent.types");
var _helpers = require("../../helpers/store/helpers");
var _UNMultipleCardsComponent = require("./UNMultipleCardsComponent.utils");
var _unitComponentsMessages = require("../../messages/webMessages/unitComponentsMessages");
var _onLoadMessage = require("../../messages/webMessages/onLoadMessage");
var _multipleCardsMessage = require("../../messages/webMessages/multipleCardsMessage");
var _UNBaseView = require("../../nativeComponents/UNBaseView");
var _useListenerToEvent = require("../../hooks/useListenerToEvent");
var _cardMessage = require("../../messages/webMessages/cardMessage");
var _bottomSheet = require("../../types/internal/bottomSheet.types");
var _reactRedux = require("react-redux");
var _SharedEventsSlice = require("../../slices/SharedEventsSlice");
var _bottomSheetMessage = require("../../messages/nativeMessages/bottomSheetMessage");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const DEFAULT_HEIGHT = _reactNative.Dimensions.get('window').height * 0.5;
const UNMultipleCardsComponent = props => {
  const dispatch = (0, _reactRedux.useDispatch)();
  const webRef = (0, _react.useRef)(null);
  const [defaultHeight, setDefaultHeight] = (0, _react.useState)();
  const dispatchCardStatusChanged = card => {
    (0, _UNMultipleCardsComponent.injectCardStatusChangedEvent)(webRef.current, card);
  };
  const dispatchMultipleCardsFiltersChanged = query => {
    (0, _UNMultipleCardsComponent.injectMultipleCardsFiltersChanged)(webRef.current, query);
  };
  const dispatchCardCreated = card => {
    (0, _UNMultipleCardsComponent.injectCardCreated)(webRef.current, card);
  };
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _cardMessage.CardMessage.CARD_STATUS_CHANGED,
    action: dispatchCardStatusChanged
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _multipleCardsMessage.MultipleCardsMessage.UNIT_MULTIPLE_CARDS_FILTERS_CHANGED,
    action: dispatchMultipleCardsFiltersChanged
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _cardMessage.CardMessage.CARD_CREATED,
    action: dispatchCardCreated
  });
  const cardClicked = card => {
    if (props.onCardClicked) {
      props.onCardClicked(card);
    }
  };
  const handleUnitOnLoad = response => {
    if (!props.onLoad) {
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.errors in response) {
      props.onLoad(response);
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.cards in response) {
      props.onLoad(response[_onLoadMessage.RESPONSE_KEYS.cards]);
      return;
    }
    console.error('On Load Error: unexpected response type');
    return;
  };
  const handleWebViewMessage = message => {
    if (!message || !message.details) return;
    switch (message.type) {
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_ON_LOAD:
        handleUnitOnLoad(message.details);
        break;
      case _pageMessage.PageMessage.PAGE_HEIGHT:
        {
          const currentHeight = message.details.height;
          currentHeight === 0 && setDefaultHeight(DEFAULT_HEIGHT);
          break;
        }
      case _multipleCardsMessage.MultipleCardsMessage.UNIT_MULTIPLE_CARDS_CARD_CLICKED:
        {
          cardClicked(message.details);
          break;
        }
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_RENDERING:
        {
          const slotData = {
            componentName: _webComponent.WebComponentType.multipleCards,
            componentResourceId: undefined,
            requestRenderingEvent: message.details
          };
          const data = {
            type: _bottomSheet.BottomSheetRenderingType.Slot,
            data: slotData
          };
          dispatch((0, _SharedEventsSlice.setEvent)({
            key: _bottomSheetMessage.BottomSheetNativeMessage.REQUEST_RENDERING,
            data
          }));
          break;
        }
    }
  };
  const style = defaultHeight ? {
    height: defaultHeight
  } : {
    flex: 1
  };
  return /*#__PURE__*/_react.default.createElement(_UNBaseView.UNBaseView, {
    style: style,
    onLoadError: handleUnitOnLoad,
    fallback: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null)
  }, /*#__PURE__*/_react.default.createElement(_WebComponent.WebComponent, {
    ref: webRef,
    type: _webComponent.WebComponentType.multipleCards,
    presentationMode: _webComponent.PresentationMode.Inherit,
    params: (0, _UNMultipleCardsComponent.getMultipleCardsParams)(props),
    script: (0, _UNMultipleCardsComponent.getMultipleCardsScript)(),
    onMessage: message => handleWebViewMessage(message),
    nestedScrollEnabled: true,
    theme: props.theme,
    language: props.language
  }));
};
var _default = exports.default = (0, _helpers.withReduxStore)(UNMultipleCardsComponent);
//# sourceMappingURL=UNMultipleCardsComponent.js.map