"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _unitComponentsMessages = require("../../messages/webMessages/unitComponentsMessages");
var _WebComponent = require("../../webComponent/WebComponent");
var _webComponent = require("../../types/internal/webComponent.types");
var _helpers = require("../../helpers/store/helpers");
var _UNPayeeManagementComponent = require("./UNPayeeManagementComponent.utils");
var _bottomSheet = require("../../types/internal/bottomSheet.types");
var _reactRedux = require("react-redux");
var _SharedEventsSlice = require("../../slices/SharedEventsSlice");
var _bottomSheetMessage = require("../../messages/nativeMessages/bottomSheetMessage");
var _useListenerToEvent = require("../../hooks/useListenerToEvent");
var _reactNativePlaidLinkSdk = require("react-native-plaid-link-sdk");
var _plaidMessages = require("../../messages/webMessages/plaidMessages");
var _payeeManagementMessage = require("../../messages/webMessages/payeeManagementMessage");
var _UNBaseView = require("../../nativeComponents/UNBaseView");
var _onLoadMessage = require("../../messages/webMessages/onLoadMessage");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const UNPayeeManagementComponent = props => {
  const dispatch = (0, _reactRedux.useDispatch)();
  const webRef = (0, _react.useRef)(null);
  const requestRefresh = data => {
    (0, _UNPayeeManagementComponent.injectRefreshEventIfNeeded)(webRef.current, data);
  };
  const openPlaid = openPlaidData => {
    (0, _UNPayeeManagementComponent.injectUnitOpenPlaid)(webRef.current, openPlaidData);
    const linkToken = openPlaidData.plaidLinkToken.attributes.linkToken;
    linkToken && (0, _reactNativePlaidLinkSdk.openLink)({
      tokenConfig: {
        noLoadingState: false,
        token: linkToken
      },
      onSuccess: success => {
        (0, _UNPayeeManagementComponent.injectUnitPlaidResponse)(webRef.current, success);
      },
      onExit: exit => {
        (0, _UNPayeeManagementComponent.injectUnitPlaidExit)(webRef.current, exit.error);
      }
    }).catch(e => {
      console.error(e);
    });
  };
  const reportCounterpartyDeleted = counterparty => {
    props.onCounterpartyDeleted && props.onCounterpartyDeleted(counterparty);
  };
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_REFRESH,
    action: requestRefresh
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _plaidMessages.PlaidMessage.UNIT_OPEN_PLAID,
    action: openPlaid
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _payeeManagementMessage.PayeeManagementMessage.UNIT_COUNTERPARTY_DELETED,
    action: reportCounterpartyDeleted
  });
  const handleRequestRendering = requestRenderingEvent => {
    switch (requestRenderingEvent.data.nativeComponentName) {
      default:
        {
          const slotData = {
            componentName: requestRenderingEvent.data.nativeComponentName,
            requestRenderingEvent: requestRenderingEvent
          };
          const data = {
            type: _bottomSheet.BottomSheetRenderingType.Slot,
            data: slotData
          };
          dispatch((0, _SharedEventsSlice.setEvent)({
            key: _bottomSheetMessage.BottomSheetNativeMessage.REQUEST_RENDERING,
            data
          }));
        }
    }
  };
  const handleUnitOnLoad = response => {
    if (!props.onLoad) {
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.errors in response) {
      props.onLoad(response);
      return;
    }
    if (_onLoadMessage.RESPONSE_KEYS.counterpartiesResult in response) {
      props.onLoad(response[_onLoadMessage.RESPONSE_KEYS.counterpartiesResult]);
      return;
    }
    console.error('On Load Error: unexpected response type');
    return;
  };
  const handleMessage = message => {
    switch (message.type) {
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_RENDERING:
        {
          const requestRenderingEvent = message.details;
          handleRequestRendering(requestRenderingEvent);
          break;
        }
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_ON_LOAD:
        {
          handleUnitOnLoad(message.details);
          break;
        }
      case _payeeManagementMessage.PayeeManagementMessage.UNIT_CONNECTED_ACCOUNT_CREATED:
        {
          const account = message.details.account;
          props.onConnectedAccountCreated && props.onConnectedAccountCreated(account);
          break;
        }
      case _payeeManagementMessage.PayeeManagementMessage.UNIT_COUNTERPARTY_CREATED:
        {
          const counterparty = message.details.counterparty;
          props.onCounterpartyCreated && props.onCounterpartyCreated(counterparty);
          break;
        }
      case _payeeManagementMessage.PayeeManagementMessage.UNIT_MICRO_DEPOSIT_CONNECTION_CREATED:
        {
          const counterparty = message.details.account;
          props.onMicroDepositConnectionCreated && props.onMicroDepositConnectionCreated(counterparty);
          break;
        }
      case _payeeManagementMessage.PayeeManagementMessage.UNIT_MICRO_DEPOSIT_CONNECTION_REJECTED:
        {
          const account = message.details.account;
          props.onMicroDepositConnectionRejected && props.onMicroDepositConnectionRejected(account);
          break;
        }
    }
  };
  return /*#__PURE__*/_react.default.createElement(_UNBaseView.UNBaseView, {
    style: {
      height: '100%'
    },
    fallback: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null)
  }, /*#__PURE__*/_react.default.createElement(_WebComponent.WebComponent, {
    ref: webRef,
    type: _webComponent.WebComponentType.payeeManagement,
    presentationMode: _webComponent.PresentationMode.Inherit,
    params: (0, _UNPayeeManagementComponent.getPayeeParams)(props),
    script: (0, _UNPayeeManagementComponent.getPayeeManagementScript)(),
    theme: props.theme,
    nestedScrollEnabled: true,
    language: props.language,
    onMessage: message => handleMessage(message)
  }));
};
var _default = exports.default = (0, _helpers.withReduxStore)(UNPayeeManagementComponent);
//# sourceMappingURL=UNPayeeManagementComponent.js.map