"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _WebComponent = require("../../webComponent/WebComponent");
var _helpers = require("../../helpers/store/helpers");
var _webComponent = require("../../types/internal/webComponent.types");
var _unitComponentsMessages = require("../../messages/webMessages/unitComponentsMessages");
var _bottomSheet = require("../../types/internal/bottomSheet.types");
var _SharedEventsSlice = require("../../slices/SharedEventsSlice");
var _bottomSheetMessage = require("../../messages/nativeMessages/bottomSheetMessage");
var _reactRedux = require("react-redux");
var _useListenerToEvent = require("../../hooks/useListenerToEvent");
var _UNWhiteLabelAppComponent = require("./UNWhiteLabelAppComponent.utils");
var _unitStore = require("../../types/internal/unitStore.types");
var _pageMessage = require("../../messages/webMessages/pageMessage");
var _UNStoreModuleHelper = _interopRequireDefault(require("../../nativeModulesHelpers/UNStoreModuleHelper/UNStoreModuleHelper"));
var _activityMessage = require("../../messages/webMessages/activityMessage");
var _windowUnitStore = require("../../utils/windowUnitStore");
var _UNBaseView = require("../../nativeComponents/UNBaseView");
var _UnitComponentsSdkManager = require("../../unitComponentsSdkManager/UnitComponentsSdkManager");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const UNWhiteLabelAppComponent = props => {
  const webRef = (0, _react.useRef)(null);
  const dispatch = (0, _reactRedux.useDispatch)();
  const handleWebViewMessage = message => {
    switch (message.type) {
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_RENDERING:
        {
          const slotData = {
            componentName: _webComponent.WebComponentType.whiteLabelApp,
            requestRenderingEvent: message.details
          };
          const data = {
            type: _bottomSheet.BottomSheetRenderingType.Slot,
            data: slotData
          };
          dispatch((0, _SharedEventsSlice.setEvent)({
            key: _bottomSheetMessage.BottomSheetNativeMessage.REQUEST_RENDERING,
            data
          }));
          break;
        }
      case _unitComponentsMessages.UnitComponentsMessage.UNIT_WHITE_LABEL_APP_ON_LOAD:
        {
          const data = message.details;
          if (data.attributes.customerToken) {
            _UnitComponentsSdkManager.UnitComponentsSDK.setCustomerToken(data.attributes.customerToken);
            _UNStoreModuleHelper.default.saveValue(_unitStore.UserDataKeys.unitCustomerToken, data.attributes.customerToken);
            // Upon receiving a new token, the web interface updates the window. Therefore, we (only) store it for subsequent windows.
            // updateWindowUnitStore();
          }
          break;
        }
      case _pageMessage.PageMessage.PAGE_LOADED:
        updateWindowUnitStore();
    }
  };
  const updateWindowUnitStore = async () => {
    /**
     * The 2FA-token (verifiedToken) is managed for all the components in UNWebComponent.
     */
    try {
      const token = await _UNStoreModuleHelper.default.getValue(_unitStore.UserDataKeys.unitCustomerToken);
      if (token) {
        (0, _windowUnitStore.setItemInWindowUnitStore)(webRef.current, _unitStore.UserDataKeys.unitCustomerToken, token);
      }
    } catch (e) {
      console.log(e);
    }
  };
  const requestRefresh = data => {
    (0, _UNWhiteLabelAppComponent.injectRefreshEventIfNeeded)(webRef.current, data);
  };
  const dispatchActivityFiltersChanged = query => {
    webRef.current?.injectJavaScript(`dispatchActivityFilterChangedEvent('${query}')`);
  };
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _unitComponentsMessages.UnitComponentsMessage.UNIT_REQUEST_REFRESH,
    action: requestRefresh
  });
  (0, _useListenerToEvent.useListenerToEvent)({
    busEventKey: _activityMessage.ActivityMessage.UNIT_ACTIVITY_FILTERS_CHANGED,
    action: dispatchActivityFiltersChanged
  });
  const renderWebView = () => {
    return /*#__PURE__*/_react.default.createElement(_UNBaseView.UNBaseView, {
      style: {
        flex: 1
      }
    }, /*#__PURE__*/_react.default.createElement(_WebComponent.WebComponent, {
      ref: webRef,
      type: _webComponent.WebComponentType.whiteLabelApp,
      presentationMode: _webComponent.PresentationMode.Inherit,
      params: (0, _UNWhiteLabelAppComponent.getWhiteLabelAppParams)(props),
      onMessage: handleWebViewMessage,
      isScrollable: true,
      theme: props.theme,
      language: props.language,
      script: (0, _UNWhiteLabelAppComponent.getWhiteLabelAppScript)()
    }));
  };
  return renderWebView();
};
var _default = exports.default = (0, _helpers.withReduxStore)(UNWhiteLabelAppComponent);
//# sourceMappingURL=UNWhiteLabelAppComponent.js.map