"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UnitComponentsSDK = void 0;
var _reactNative = require("react-native");
var _UnitComponentsSdk = require("./UnitComponentsSdk.api");
var _unitComponentsUiManager = require("./unitComponentsUiManager/unitComponentsUiManager");
var _webVersioningStrategy = require("../utils/webVersioningStrategy.utils");
var _UnitComponentsSdk2 = require("./UnitComponentsSdk.constants");
var _ConfigurationSlice = require("../slices/ConfigurationSlice");
var _store = require("../store/store");
var _unitStore = require("../types/internal/unitStore.types");
var _UNStoreModuleHelper = _interopRequireDefault(require("../nativeModulesHelpers/UNStoreModuleHelper/UNStoreModuleHelper"));
var _UnitComponentsHelpersManager = require("./unitComponentsHelpersManager/UnitComponentsHelpersManager");
var _UNSecurityHelper = _interopRequireDefault(require("../nativeModulesHelpers/UNSecurityHelper"));
var _securitySettings = require("../types/shared/securitySettings");
var _UNSnapshotProtectionHelper = _interopRequireDefault(require("../nativeModulesHelpers/UNSanpshotProtectionHelper/UNSnapshotProtectionHelper"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class UnitComponentsSDK {
  static securitySettings = _UnitComponentsSdk2.UNComponentsSDKConstants.securitySettings;
  static sdkVersion = '2.1.0';
  static init = async (env, theme, language, fonts, webVersioningStrategy = _UnitComponentsSdk2.UNComponentsSDKConstants.webSDKRecommendedStrategy, securitySettings = _UnitComponentsSdk2.UNComponentsSDKConstants.securitySettings) => {
    try {
      this.webVersioningStrategy = webVersioningStrategy;
      this.ui = new _unitComponentsUiManager.UnitComponentsUiManager();
      this.helpers = new _UnitComponentsHelpersManager.UnitComponentsHelpersManager();
      const isJailbroke = await _UNSecurityHelper.default.isDeviceJailbroke();
      if (isJailbroke) {
        throw Error('Device is jailbroke');
      }
      this.env = env;
      this.securitySettings = securitySettings;
      this.fonts = fonts;
      _store.store.dispatch((0, _ConfigurationSlice.setTheme)(theme));
      _store.store.dispatch((0, _ConfigurationSlice.setLanguage)(language));
      (0, _webVersioningStrategy.warnClientIfNeeded)(this.webVersioningStrategy);
      const shouldProtectFromSnapshot = securitySettings.snapshotProtectionStrategy != _securitySettings.UNComponentsSnapshotProtectionStrategy.None;
      if (_reactNative.Platform.OS === 'ios') {
        _UNSnapshotProtectionHelper.default.setIosSecurity(shouldProtectFromSnapshot, 'light');
      }
      await (0, _UnitComponentsSdk.fetchUnitScript)();
    } catch (e) {
      console.log(e);
    }
  };
  static isInitialized = () => {
    return this.env != undefined;
  };
  static setPushProvisioningModule = pushProvisionModule => {
    this.pushProvisionModule = pushProvisionModule;
  };
  static getPushProvisionModule = () => {
    return this.pushProvisionModule;
  };
  static getSecuritySettings = () => {
    return this.securitySettings;
  };

  /**
   * @deprecated - Unit SDK is managing the signedNonce, no need to provide it
   */
  static setSignedNonce = signedNonce => {
    this.signedNonce = signedNonce;
  };
  static getEnv = () => {
    return this.env;
  };
  static getWebVersioningStrategy = () => {
    return this.webVersioningStrategy;
  };
  static getFonts = () => {
    return this.fonts;
  };

  /**
   * @deprecated - Unit SDK is managing the signedNonce, no need to provide it
   */
  static getSignedNonce = () => {
    return this.signedNonce;
  };
  static setCustomerToken = customerToken => {
    _store.store.dispatch((0, _ConfigurationSlice.setCustomerToken)(customerToken));
  };
  static getSdkVersion = () => {
    return this.sdkVersion;
  };
  static cleanUserData = () => {
    _UNStoreModuleHelper.default.cleanValue(_unitStore.UserDataKeys.unitCustomerToken);
    _UNStoreModuleHelper.default.cleanValue(_unitStore.UserDataKeys.unitVerifiedToken);
  };
}
exports.UnitComponentsSDK = UnitComponentsSDK;
//# sourceMappingURL=UnitComponentsSdkManager.js.map