import type {
  UNAccount,
  UNCard,
  UNComponentsError,
  UNComponentsOnLoadResponseData,
  UNAuthorization,
  UNCounterparty,
  UNTransaction,
  UNCreateCardComponentResources
} from '../../types/shared';

export enum RESPONSE_KEYS {
  errors = 'errors',
  card = 'cardResult',
  cards = 'cardsResult',
  account = 'accountResult',
  counterpartyAccount = 'counterpartyResult',
  transactions = 'transactionsResult',
  authorizations = 'authorizationsResult',
  repayment = 'repaymentResult',
  accountCards = 'accountCardsResult',
  counterpartiesResult = 'counterpartiesResult',
  createCardResult = 'createCardResult'
}

export type CardsOnLoadResponse = {
  [RESPONSE_KEYS.cards]: UNComponentsOnLoadResponseData<[UNCard]>
}
export type CardOnLoadResponse = {
  [RESPONSE_KEYS.card]: UNComponentsOnLoadResponseData<UNCard>
}

export type AccountOnLoadResponse = {
  [RESPONSE_KEYS.account]: UNComponentsOnLoadResponseData<UNAccount>
}

export type AccountsOnLoadResponse = {
  [RESPONSE_KEYS.account]: UNComponentsOnLoadResponseData<[UNAccount]>
}

export type ACHOnLoadResponse = {
  [RESPONSE_KEYS.account]: UNComponentsOnLoadResponseData<UNAccount> | UNComponentsOnLoadResponseData<[UNAccount]>,
  [RESPONSE_KEYS.counterpartyAccount]: UNComponentsOnLoadResponseData<[UNCounterparty]>
}

export type ActivityOnLoadResponse = {
  [RESPONSE_KEYS.authorizations]: UNComponentsOnLoadResponseData<[UNAuthorization]>,
  [RESPONSE_KEYS.transactions]: UNComponentsOnLoadResponseData<[UNTransaction]>
}

export type PayeeManagementOnLoadResponse = {
  [RESPONSE_KEYS.counterpartiesResult]: UNComponentsOnLoadResponseData<[UNCounterparty]>
}

export type CreateCardOnLoadResponse = {
  [RESPONSE_KEYS.createCardResult]: UNComponentsOnLoadResponseData<UNCreateCardComponentResources>
}

export type UnitOnLoadResponseSuccessData =
  | CardOnLoadResponse
  | CardsOnLoadResponse
  | ACHOnLoadResponse
  | AccountsOnLoadResponse
  | AccountOnLoadResponse
  | ActivityOnLoadResponse
  | PayeeManagementOnLoadResponse
  | CreateCardOnLoadResponse

export type UnitOnLoadResponseEvent =
  | UNComponentsError
  | UnitOnLoadResponseSuccessData
