import { UNActivityType } from '../shared';
import { UNCents } from './payment/payments.types';

export type UNCheckDeposit = {
  id: string
  type: UNActivityType
  attributes: {
    createdAt: Date
    status: keyof typeof UNCheckDepositStatus
    reason?: string
    reasonText?: string
    description: string
    amount: UNCents
    vendor?: UNCheckDepositVendors
    checkNumber?: string
    counterparty?: UNCheckCounterparty
    frontImage?: string
    backImage?: string
    settlementDate?: Date
    statusCreatedAt?: Date
    statusSetBy?: string
    statusHistory?: UNStatusEvent[]
    tags?: { [key: string]: string }
  }
  relationships: {
    account: {
      data: {
        type: string
        id: string
      }
    }
    customer?: {
      data: {
        type: string
        id: string
      }
    }
    customers?: {
      data: [
        {
          type: 'customer'
          id: string
        }
      ]
    }
    org?: {
      data: {
        type: 'org'
        id: string
      }
    }
    transaction?: {
      data: {
        type: UNActivityType.Transaction
        id: string
      }
    }
  }
}

export enum UNCheckDepositStatus {
  AwaitingImages = 'AwaitingImages',
  AwaitingFrontImage = 'AwaitingFrontImage',
  AwaitingBackImage = 'AwaitingBackImage',
  PendingReview = 'PendingReview',
  AwaitingCustomerConfirmation = 'AwaitingCustomerConfirmation',
  Pending = 'Pending',
  Rejected = 'Rejected',
  Clearing = 'Clearing',
  Sent = 'Sent',
  Canceled = 'Canceled',
  Returned = 'Returned',
}

export type UNCheckCounterparty = {
  name: string
  accountNumber: string
  routingNumber: string
}

export type UNStatusEvent = {
  status: {
    [key: string]: any
  }
  updatedAt: Date
  updatedBy?: string
}

export enum UNCheckDepositVendors {
  Ensenta = 'Ensenta',
  Smartpay = 'Smartpay',
}