import { Platform } from 'react-native';
import {
  DISPATCH_RENDERING_EVENT,
  LISTENERS,
  POST_MESSAGE_TO_SDK,
  POST_PAGE_HEIGHT,
  DISPATCH_REQUEST_CARD_ACTION,
  DISPATCH_OPEN_ACTIONS_MENU,
  DISPATCH_REQUEST_ACCOUNT_ACTION,
  DISPATCH_ACTIVITY_FILTER_CHANGED_EVENT,
  DISPATCH_REQUEST_SHOW_SENSITIVE_DATA,
  DISPATCH_REQUEST_HIDE_SENSITIVE_DATA,
  SET_ITEM_IN_WINDOW_UNIT_STORE,
  DISPATCH_EVENT_TO_CONTINUE,
  DISPATCH_CARD_STATUS_CHANGED,
  DISPATCH_MULTIPLE_CARDS_FILTER_CHANGED_EVENT,
  DISPATCH_CARD_CREATED_EVENT
} from '../scripts/html/bodyScript';

export const HTML_PLACEHOLDER = {
  SCRIPT_UNIT: '<SCRIPT_UNIT>',
  BODY: '<BODY_HTML_CODE>',
  SCRIPT_FROM_NATIVE: '<SCRIPT_FROM_NATIVE>',
  WINDOW_PARAMS: '<WINDOW_PARAMS>',
  FONT_FACES: '<FONT_FACES>',
};

const htmlText = `
  <!DOCTYPE html>
  <html lang="en">

  <head lang="en">
    <title>Unit Web SDK Demo</title>
    <script>
    window.UnitMobileSDK = true
    window.UnitStore = {}
    window.UnitSessionStore = {}
    window.UnitMobileSDKConfig = {
      os: "${Platform.OS}",
      walletName: "${Platform.OS === 'ios' ? 'Apple' : 'Google'}",
    }
    ${HTML_PLACEHOLDER.WINDOW_PARAMS}
    </script>
    <meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=0">

    <style type="text/css">
      ${HTML_PLACEHOLDER.FONT_FACES}

      body {
        margin: 0;
      }
    </style>
  </head>

  <body>
    ${HTML_PLACEHOLDER.BODY}

    <script>
      ${POST_MESSAGE_TO_SDK}

      ${POST_PAGE_HEIGHT}

      ${LISTENERS.isPageLoaded}

      ${LISTENERS.onLoad}

      ${LISTENERS.unitRequestDownload}

      ${LISTENERS.requestRendering}

      ${LISTENERS.requestOpenLink}

      ${LISTENERS.requestCloseFlow}

      ${LISTENERS.cardActivated}

      ${LISTENERS.cardStatusChange}

      ${LISTENERS.cardCreated}

      ${LISTENERS.unitCounterpartyDeleted}

      ${LISTENERS.unitRequestExternalSdk}

      ${LISTENERS.unitOpenPlaid}

      ${LISTENERS.unitAccountChanged}

      ${LISTENERS.unitActivityFiltersChanged}

      ${LISTENERS.unitMultipleCardsFiltersChanged}

      ${LISTENERS.unitMultiFactorAuthFinished}

      ${LISTENERS.unitUnauthorizedToken}

      ${DISPATCH_RENDERING_EVENT}

      ${DISPATCH_EVENT_TO_CONTINUE}

      ${DISPATCH_CARD_STATUS_CHANGED}

      ${DISPATCH_OPEN_ACTIONS_MENU}

      ${DISPATCH_REQUEST_HIDE_SENSITIVE_DATA}

      ${DISPATCH_REQUEST_SHOW_SENSITIVE_DATA}

      ${DISPATCH_REQUEST_CARD_ACTION}

      ${DISPATCH_ACTIVITY_FILTER_CHANGED_EVENT}

      ${DISPATCH_MULTIPLE_CARDS_FILTER_CHANGED_EVENT}

      ${DISPATCH_CARD_CREATED_EVENT}

      ${DISPATCH_REQUEST_ACCOUNT_ACTION}

      ${SET_ITEM_IN_WINDOW_UNIT_STORE}

      ${HTML_PLACEHOLDER.SCRIPT_FROM_NATIVE}
    </script>
  </body>
  </html>
`;

export default htmlText;
